Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1770)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/compositor/bottombar/contextualsearch/ContextualSearchBarControl.java

Issue 2798123002: Remove crushed sprite resource and layer (Closed)
Patch Set: Rebase and fix my nits Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/compositor/bottombar/contextualsearch/ContextualSearchBarControl.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/compositor/bottombar/contextualsearch/ContextualSearchBarControl.java b/chrome/android/java/src/org/chromium/chrome/browser/compositor/bottombar/contextualsearch/ContextualSearchBarControl.java
index 5946d8580dbe65de273307ca5233540ff5180e6d..2cebd438538666629075fc6fd26945c52d0c4096 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/compositor/bottombar/contextualsearch/ContextualSearchBarControl.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/compositor/bottombar/contextualsearch/ContextualSearchBarControl.java
@@ -196,11 +196,11 @@ public class ContextualSearchBarControl
// instead. If the panel is fully peeked, call #onUpdateFromPeekToExpanded().
if (percentage == 1.f) onUpdateFromPeekToExpand(0.f);
// When the panel is completely closed the caption and static image should be hidden.
if (percentage == 0.f) {
mQuickActionControl.reset();
mCaptionControl.hide();
- getImageControl().hideStaticImage(false);
+ getImageControl().hideCustomImage(false);
}
}
@@ -196,11 +196,11 @@ public class ContextualSearchBarControl
// instead. If the panel is fully peeked, call #onUpdateFromPeekToExpanded().
if (percentage == 1.f) onUpdateFromPeekToExpand(0.f);
- // When the panel is completely closed the caption and static image should be hidden.
+ // When the panel is completely closed the caption and custom image should be hidden.
if (percentage == 0.f) {
mQuickActionControl.reset();

Powered by Google App Engine
This is Rietveld 408576698